@@ -12,11 +12,17 @@ class ConnectionInline(admin.TabularInline):
 
 
 class ContactAdmin(admin.ModelAdmin):
-    inlines = [
-        ConnectionInline,
-    ]
+    inlines = (ConnectionInline,)
+
+
+class ConnectionAdmin(admin.ModelAdmin):
+    list_display = ('id', 'backend', 'identity', 'contact')
+    list_filter = ('backend',)
+    search_fields = ('identity',)
+    raw_id_fields = ('contact',)
+
 
 admin.site.register(App)
 admin.site.register(Backend)
-admin.site.register(Connection)
+admin.site.register(Connection, ConnectionAdmin)
 admin.site.register(Contact, ContactAdmin)
