@@ -1,13 +1,17 @@
 #!/usr/bin/env python
 # vim: ai ts=4 sts=4 et sw=4
 
+from django.contrib.auth.decorators import login_required
 from django.shortcuts import render
+
 from rapidsms.contrib.messagelog.tables import MessageTable
 from rapidsms.contrib.messagelog.models import Message
 from rapidsms import settings
+
 from django_tables2 import RequestConfig
 
 
+@login_required
 def message_log(request):
     qset = Message.objects.all()
     qset = qset.select_related('contact', 'connection__backend')
